import * as React from "react";
import * as ReactDOM from "react-dom";
import { process } from "@progress/kendo-data-query";
import '@progress/kendo-theme-default/dist/all.css';
import { Grid, GridColumn as Column } from "@progress/kendo-react-grid";
import { ColumnMenu, ColumnMenuCheckboxFilter } from "./columnMenu";
import { sampleProducts } from "./sample-products";
import { filterBy } from '@progress/kendo-data-query';

const createDataState = (dataState) => {
    return {
        result: process(sampleProducts.slice(0), dataState),
        dataState: dataState,
    };
};

export default function KendoDataGridComponent() {
    let initialState = createDataState({
        take: 8,
        skip: 0,
    });
    const [result, setResult] = React.useState(initialState.result);
    const [dataState, setDataState] = React.useState(initialState.dataState);
    const dataStateChange = (event) => {
        let updatedState = createDataState(event.dataState);
        setResult(updatedState.result);
        setDataState(updatedState.dataState);
    };

    return (
        <Grid
            data={result}
            {...dataState}
            onDataStateChange={dataStateChange}
            sortable={true}
            pageable={true}
            pageSize={8}
        >
            <Column field="schoolName" title="School Name" columnMenu={ColumnMenu} />
            <Column field="schoolCode" title="School Code" columnMenu={ColumnMenu}  />
            <Column field="recordId" format="{0:c}" title="Record Id" columnMenu={ColumnMenu} />
            <Column field="actualValue" title="Actual Value" columnMenu={ColumnMenu} />
            <Column field="type" title="Type" columnMenu={ColumnMenu} />
            <Column field="errorCode" title="Error Code" columnMenu={ColumnMenu} />
            <Column field="errorDescription" title="Error Desc" columnMenu={ColumnMenu} />
            <Column field="errorGroup" title="Error Group" columnMenu={ColumnMenu} />
        </Grid>
    );
}